crabnet.data.benchmark\_data.CritExam\_\_Ef package
===================================================

Module contents
---------------

.. automodule:: crabnet.data.benchmark_data.CritExam__Ef
   :members:
   :undoc-members:
   :show-inheritance:
